nx.graphic.Topology.USMapLayout - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.USMapLayout Class

Module: nx.graphic.Topology

US map layout class, this require d3.js

    files:
    http://d3js.org/d3.v3.min.js

example

    var topo = new nx.graphic.Topology({
       adaptive: true,
       nodeConfig: {
                       label: 'model.name'
                   },
       showIcon: false,
       layoutType: 'USMap',
       layoutConfig: {
           longitude: 'model.longitude',
           latitude: 'model.latitude'
       },
       data: topologyData
    })

- Index
- Properties

## Item Index

### Properties

- latitude
- longitude

## Properties

### `latitude`

Unknown

Map's latitude attribute

### `longitude`

Unknown

Map's longitude attribute